Index: webrtc/media/base/audiosource.h |
diff --git a/webrtc/media/base/audiorenderer.h b/webrtc/media/base/audiosource.h |
similarity index 66% |
rename from webrtc/media/base/audiorenderer.h |
rename to webrtc/media/base/audiosource.h |
index 4544c7fc634aeb96cb56b922df5929199e8b3664..7dd5341a11cebf419e190a431dab7ca9b5ef8283 100644 |
--- a/webrtc/media/base/audiorenderer.h |
+++ b/webrtc/media/base/audiosource.h |
@@ -8,40 +8,40 @@ |
* be found in the AUTHORS file in the root of the source tree. |
*/ |
-#ifndef WEBRTC_MEDIA_BASE_AUDIORENDERER_H_ |
-#define WEBRTC_MEDIA_BASE_AUDIORENDERER_H_ |
+#ifndef WEBRTC_MEDIA_BASE_AUDIOSOURCE_H_ |
the sun
2016/03/03 15:15:24
I like this change because I've always found this
Taylor Brandstetter
2016/03/04 16:06:56
I wish we could just get rid of this class and use
|
+#define WEBRTC_MEDIA_BASE_AUDIOSOURCE_H_ |
#include <cstddef> |
namespace cricket { |
-// Abstract interface for rendering the audio data. |
-class AudioRenderer { |
+// Abstract interface for providing the audio data. |
+class AudioSource { |
public: |
class Sink { |
public: |
// Callback to receive data from the AudioRenderer. |
virtual void OnData(const void* audio_data, |
int bits_per_sample, |
int sample_rate, |
size_t number_of_channels, |
size_t number_of_frames) = 0; |
// Called when the AudioRenderer is going away. |
virtual void OnClose() = 0; |
protected: |
virtual ~Sink() {} |
}; |
// Sets a sink to the AudioRenderer. There can be only one sink connected |
// to the renderer at a time. |
virtual void SetSink(Sink* sink) {} |
the sun
2016/03/03 15:15:24
= 0
Taylor Brandstetter
2016/03/04 16:06:56
Done.
|
protected: |
- virtual ~AudioRenderer() {} |
+ virtual ~AudioSource() {} |
}; |
} // namespace cricket |
-#endif // WEBRTC_MEDIA_BASE_AUDIORENDERER_H_ |
+#endif // WEBRTC_MEDIA_BASE_AUDIOSOURCE_H_ |
@@ -8,40 +8,40 @@ |
class Sink { |
public: |
- // Callback to receive data from the AudioRenderer. |
+ // Callback to receive data from the AudioSource. |
virtual void OnData(const void* audio_data, |
int bits_per_sample, |
@@ -8,40 +8,40 @@ |
size_t number_of_channels, |
size_t number_of_frames) = 0; |
- // Called when the AudioRenderer is going away. |
+ // Called when the AudioSource is going away. |
virtual void OnClose() = 0; |
protected: |
@@ -8,40 +8,40 @@ |
virtual ~Sink() {} |
}; |
- // Sets a sink to the AudioRenderer. There can be only one sink connected |
- // to the renderer at a time. |
+ // Sets a sink to the AudioSource. There can be only one sink connected |
+ // to the source at a time. |
virtual void SetSink(Sink* sink) {} |
the sun